@@ -1044,7 +1044,7 @@ void design2str(const matrix <double, n_rowsD,n_attr> &design, const int n_obser
 
 
 
-void cppAdaptive(const int threads, const string &obsVector, string &futVector, string &betaVector, const int n_observed)
+void cppAdaptive( const string &obsVector, string &futVector, string &betaVector, const int n_observed, const int threads )
 {
 
   // omp_set_num_threads(omp_get_max_threads());
@@ -1095,7 +1095,7 @@ int main()
   string betaVector = "-0.26425,0.648666,-0.0565359,-0.373203,-0.107654,0.228433,-0.339707,0.663967,0.0600106,0.0828479";
   int n_observed = 4;
 
-  cppAdaptive(2, obsVector, futVector, betaVector, n_observed);
+  cppAdaptive( obsVector, futVector, betaVector, n_observed, 1 );
 
   // cout << "betaVector: \n" << betaVector << endl;
   // cout << "futVector: \n" << futVector << endl;
